scoretools.get_first_score_in_proper_parentage_of_component
===========================================================

.. autofunction:: abjad.tools.scoretools.get_first_score_in_proper_parentage_of_component.get_first_score_in_proper_parentage_of_component
